{ config, lib, pkgs, ... }:
{
  options.system.nvidia.enable = lib.mkEnableOption "Enable the Nvidia graphics stack";

  config = lib.mkIf config.system.nvidia.enable {
    hardware.nvidia = {
      package = config.boot.kernelPackages.nvidiaPackages.beta;
      modesetting.enable = true;
      nvidiaSettings = false;
      open = false;
    };

    services.xserver.videoDrivers = [ "nvidia" ];

    boot.kernelParams = [ "nvidia_drm.fbdev=1" ];

    nixpkgs.allowUnfreePackages = [ "nvidia-x11" ];

    specialisation.nouveau.configuration.config = {
      system.nvidia.enable = lib.mkForce false;
      environment.sessionVariables.NIXOS_OZONE_WL = lib.mkForce "";
    };
  };
}
